parade.template.workspace.module package
========================================

Subpackages
-----------

.. toctree::

    parade.template.workspace.module.contrib
    parade.template.workspace.module.task

Module contents
---------------

.. automodule:: parade.template.workspace.module
    :members:
    :undoc-members:
    :show-inheritance:
